@@ -54,9 +54,6 @@ model = exp_cifar.Net()
 ## display network properties
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
 print("\n\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
-num_layers = len(list(model.parameters()))
-print("\nThe number of layers in the model: %d" % num_layers)
-
 
 exp_cifar.run_code_for_training(model, display_images=False)
 
