@@ -35,9 +35,8 @@ os.environ['PYTHONHASHSEED'] = str(seed)
 
 from DLStudio import *
 
-#dataroot = "/home/kak/TextDatasets/sentiment_dataset/"
 dataroot = "./data/TextDatasets/sentiment_dataset/"
-
+#dataroot = "/home/kak/TextDatasets/sentiment_dataset/"
 
 dataset_archive_train = "sentiment_dataset_train_40.tar.gz"
 #dataset_archive_train = "sentiment_dataset_train_200.tar.gz"
@@ -82,9 +81,6 @@ text_cl.load_SentimentAnalysisDataset(dataserver_train, dataserver_test)
 model = text_cl.TEXTnetOrder2WithEmbeddings(hidden_size=512, output_size=2)
 
 number_of_learnable_params = sum(p.numel() for p in model.parameters() if p.requires_grad)
-num_layers = len(list(model.parameters()))
-
-print("\n\nThe number of layers in the model: %d" % num_layers)
 print("\nThe number of learnable parameters in the model: %d" % number_of_learnable_params)
 
 text_cl.run_code_for_training_with_TEXTnetOrder2_word2vec(model, display_train_loss=True)
