@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.5.0'
+__version__   = '2.5.2'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2024-September-7'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.0.html'
-__copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
+__date__      = '2025-March-26'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.2.html'
+__copyright__ = "(C) 2025 Avinash Kak. Python Software Foundation."
 
 
 __doc__  =  '''
@@ -42,14 +42,16 @@ As just one example of my simplification of code organization, the original code
 library at GitHub uses the GaussianDiffusion class through a subclass named
 SpacedDiffusion that is defined in a utility file called script_util.py.  I got
 rid of the SpacedDiffusion class and incorporated that functionality in a rather
-small function inside the GaussianDiffusion class.  Along the same lines, I have
-also either eliminated some of the functionality associated with the UNetModel
-class or incorporated it in the definition of UNetModel itself.
+small function inside the GaussianDiffusion class.  Along the same lines, I also
+either eliminated some of the UNetModel's functionality that existed in the form
+of method definitions or incorporated those methods in the class definition for
+UNetModel.
 
 Another change I made to the UNetModel class was to make the use of "attention" an
 option in the constructor call for UNetModel.  I did so because attention does not
 seem to matter if you are using diffusion based modeling for, say, 64x64 images
---- even the images from the CelebA dataset as long as you resize them to 64x64. 
+--- or, for that matter, even larger images from the CelebA dataset as long as you
+resize them to 64x64.
 
 Obviously, the GitHub code library is much more general and will allow you to do
 the kinds of experiments (such as conditional diffusion) that my smaller version
