@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
 
-__version__   = '2.5.0'
+__version__   = '2.5.2'
 __author__    = "Avinash Kak (kak@purdue.edu)"
-__date__      = '2024-September-7'                   
-__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.0.html'
-__copyright__ = "(C) 2024 Avinash Kak. Python Software Foundation."
+__date__      = '2025-March-26'                   
+__url__       = 'https://engineering.purdue.edu/kak/distDLS/DLStudio-2.5.2.html'
+__copyright__ = "(C) 2025 Avinash Kak. Python Software Foundation."
 
 
 __doc__ = '''
