@@ -11,7 +11,7 @@ if sys.version_info[0] == 3:
     from Transformers.Transformers import TransformerFG
     from Transformers.Transformers import TransformerPreLN
     from Transformers.Transformers import visTransformer
-    from Transformers.Transformers import Autoencoder
+    from Transformers.Transformers import AutoencoderWithTransformer
 else:
     sys.exit("The transformer code in DLStudio has only been tested for Python 3")
 
